@@ -24,6 +24,7 @@ DEFAULT_SLIDESHOWS_TEMPLATE = getattr(settings, 'DEFAULT_SLIDESHOWS_TEMPLATE', '
 DEFAULT_SLIDESHOWS_CONFIG = getattr(settings, 'DEFAULT_SLIDESHOWS_CONFIG', '')
 DEFAULT_SLIDESHOWS_RANDOM_SLIDE_TEMPLATE = getattr(settings, 'DEFAULT_SLIDESHOWS_RANDOM_SLIDE_TEMPLATE', '')
 
+
 class Slideshow(models.Model):
     """
     Slideshow that contains slides
@@ -33,13 +34,15 @@ class Slideshow(models.Model):
     slug = models.SlugField(_('slug'), unique=True, max_length=75)
     template = models.CharField(_('content template'), choices=settings.SLIDESHOWS_TEMPLATES, default=DEFAULT_SLIDESHOWS_TEMPLATE, max_length=100, blank=False)
     config = models.CharField(_('config template'), choices=settings.SLIDESHOWS_CONFIGS, default=DEFAULT_SLIDESHOWS_CONFIG, max_length=100, blank=True, help_text=_('The Javascript config file to use to configure and initialize the slideshow'))
+    transition_time = models.IntegerField(_('transition time'), default=0, null=True, blank=True, help_text=_('Sets the amount of time in milliseconds before transitioning a slide. Set 0 to use default value.'))
+
 
     def __unicode__(self):
         return self.title
-    
+
     def get_published_slides(self):
         return self.slide_set.filter(publish=True)
-    
+
     def count_published_slides(self):
         return self.get_published_slides().count()
     count_published_slides.short_description = _('Published slides')
@@ -48,9 +51,10 @@ class Slideshow(models.Model):
         # First create
         if not self.created:
             self.created = datetime.datetime.now()
-        
+
         super(Slideshow, self).save(*args, **kwargs)
 
+
 class Slide(models.Model):
     """
     Slide item
@@ -63,6 +67,7 @@ class Slide(models.Model):
     content = HTMLField(_("content"), blank=True)
     image = models.ImageField(_('image'), upload_to=IMAGE_FILE_UPLOADTO, max_length=255, blank=True)
     url = models.CharField(_('url'), blank=True, max_length=255, help_text=_('An URL that can be used in the template for this entry'))
+    open_blank = models.BooleanField(_('open new window'), default=False, help_text=_('If checked the link will be open in a new window'))
 
     def __unicode__(self):
         return self.title
@@ -82,7 +87,7 @@ class Slide(models.Model):
         # First create
         if not self.created:
             self.created = datetime.datetime.now()
-        
+
         super(Slide, self).save(*args, **kwargs)
 
     class Meta:
